import request from '@/utils/request'

// 查询门店分类列表
export function listType(query) {
  return request({
    url: '/fenlei/type/list',
    method: 'get',
    params: query
  })
}

// 查询门店分类树结构
export function treeList(query) {
  return request({
    url: '/fenlei/type/treeList',
    method: 'get',
    params: query
  })
}



// 查询门店分类详细
export function getType(id) {
  return request({
    url: '/fenlei/type/' + id,
    method: 'get'
  })
}

// 新增门店分类
export function addType(data) {
  return request({
    url: '/fenlei/type',
    method: 'post',
    data: data
  })
}

// 修改门店分类
export function updateType(data) {
  return request({
    url: '/fenlei/type',
    method: 'put',
    data: data
  })
}

// 删除门店分类
export function delType(id) {
  return request({
    url: '/fenlei/type/' + id,
    method: 'delete'
  })
}
